@@ -209,11 +209,12 @@ class Drawable():
 		Draw a text annotation visualization on this Drawable.
 		The arguments and keyword arguments are those supported by :meth:`text.annotation.TextAnnotation.draw` method.
 
-		:return: The drawn text annotation.
-		:rtype: :class:`text.annotation.TextAnnotation`
+		:return: The drawn text annotation's lines.
+				 Each line is made up of tuples of lists.
+				 The first list in each tuple is the list of legend labels.
+				 The second list in each tuple is the list of actual tokens.
+		:rtype: list of tuple
 		"""
 
 		text_annotation = TextAnnotation(self)
-		text_annotation.draw(*args, **kwargs)
-
-		return text_annotation
+		return text_annotation.draw(*args, **kwargs)
